"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SecurityMiddleware = void 0;
const dino_core_1 = require("dino-core");
const client_http_exception_1 = require("../../../exception/client.http.exception");
const before_handler_middleware_1 = require("../../before.handler.middleware");
class SecurityMiddleware extends before_handler_middleware_1.BeforeHandlerMiddleware {
    configuration;
    constructor(environment, _api) {
        super();
        this.configuration = environment.getOrDefault('dino:security', { enabled: false });
    }
    /**
     * Definition of the function that will handle the security business logic associated with this middleware.
     *
     * @param {import('express').Request} req Express request instance
     * @param {import('express').Response} res express response instance
     * @param {Function} next the next function that will be invoked as part of the express chain
     */
    handle(req, _res, next) {
        if (this.configuration.enabled) {
            const authorization = req.headers.authorization;
            if (dino_core_1.ObjectHelper.isNotDefined(authorization)) {
                next(client_http_exception_1.ClientHttpException.create(401, 'Unauthorized'));
                return;
            }
        }
        next();
    }
}
exports.SecurityMiddleware = SecurityMiddleware;
//# sourceMappingURL=SecurityMiddleware.js.map