"use strict";
//    Copyright 2018 Quirino Brizi [quirino.brizi@gmail.com]
//
//    Licensed under the Apache License, Version 2.0 (the "License");
//    you may not use this file except in compliance with the License.
//    You may obtain a copy of the License at
//
//        http://www.apache.org/licenses/LICENSE-2.0
//
//    Unless required by applicable law or agreed to in writing, software
//    distributed under the License is distributed on an "AS IS" BASIS,
//    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//    See the License for the specific language governing permissions and
//    limitations under the License.
Object.defineProperty(exports, "__esModule", { value: true });
exports.PolicyFactory = void 0;
const QuotaPolicy_1 = require("./QuotaPolicy");
const RateLimitPolicy_1 = require("./RateLimitPolicy");
class PolicyFactory {
    /**
     * Get a policy object
     * @param {String} policy the policy to lookup
     * @returns {AbstractPolicy} an implementation of AbstractPolicy
     *
     * @public
     */
    getPolicy(policy) {
        if (['quotaPolicy', 'quota'].includes(policy)) {
            return new QuotaPolicy_1.QuotaPolicy();
        }
        else if (['rateLimit', 'rateLimitPolicy', 'rate'].includes(policy)) {
            return new RateLimitPolicy_1.RateLimitPolicy();
        }
        throw new Error(`unknown policy ${policy}, available are: quotaPolicy and rateLimitPolicy`);
    }
}
exports.PolicyFactory = PolicyFactory;
//# sourceMappingURL=PolicyFactory.js.map